@@ -16,7 +16,7 @@
  */
 
 /*
- * $Id: XMLUri.hpp 557254 2007-07-18 13:28:54Z amassari $
+ * $Id: XMLUri.hpp 1798769 2017-06-14 21:30:14Z rleigh $
  */
 
 #if !defined(XERCESC_INCLUDE_GUARD_XMLURI_HPP)
@@ -628,7 +628,7 @@ inline const XMLCh* XMLUri::getUriText() const
     //  we have to cast off the constness.
     //
     if (!fURIText)
-        ((XMLUri*)this)->buildFullText();
+        (const_cast<XMLUri *>(this))->buildFullText();
 
     return fURIText;
 }
